@@ -5,7 +5,7 @@ from pysudoku_package.config import get_input_files, get_pool_dicts, set_up_tmpd
 from pysudoku_package.io import txt_writer, file_compiler
 from pysudoku_package.alignment import run_bowtie2, parse_bowtie2_output
 from pysudoku_package.trimming import read_data, detect_barcodes
-from pysudoku_package.generate_count_matrix import  get_count_matrix, get_hash_ids, filter_barcodes, filter_counts
+from pysudoku_package.generate_count_matrix import  get_count_matrix, get_hash_ids, filter_barcodes, local_filter_counts, global_filter_counts
 from pysudoku_package.deconvolution import get_ambiguity, get_unambiguous_locations, coords2genes, transpose_location_summary, transpose_barcode_summary
 from pysudoku_package.predict_locations import predict_ambiguous_locations
 import multiprocessing as mp
@@ -31,6 +31,7 @@ class LibraryExperiment(object):
                  bar_upstream,
                  bar_downstream,
                  filter_thr,
+                 global_filter_thr,
                  min_counts):
         """
         
@@ -80,6 +81,7 @@ class LibraryExperiment(object):
         self.exp_design = exp_design
         self.use_barcodes = use_barcodes
         self.filter_thr = filter_thr
+        self.global_filter_thr = global_filter_thr
         self.min_counts = min_counts
         if use_barcodes:
             self.bar_upstream = bar_upstream
@@ -195,7 +197,8 @@ class LibraryExperiment(object):
         filtered_count_mat = self.count_mat
         counts = filtered_count_mat[self.pools].values.astype(float)
         counts = (counts/np.sum(counts, axis=0))*1e6
-        counts = filter_counts(counts, thr=self.filter_thr)
+        counts = global_filter_counts(counts, thr=self.global_filter_thr)
+        counts = local_filter_counts(counts, thr=self.filter_thr)
         filtered_count_mat[self.pools] = counts
         self.count_mat = filtered_count_mat
         
@@ -232,7 +235,30 @@ class LibraryExperiment(object):
             transposed_location_summary = transpose_location_summary(self, location_summary)
             self.transposed_location_summary = transposed_location_summary
             transposed_location_summary.to_csv("well_location_summary.csv", index=False)
-
+        
+    def deconvolve_validation(self, barcode_only=False):
+        """
+        Deconvolve mutant count matrix and return summary output with 
+        genes names.
+        
+        """
+        # normalize to library size and filter low reads
+        filtered_count_mat = self.count_mat
+        counts = filtered_count_mat[self.pools].values.astype(float)
+        counts = (counts/np.sum(counts, axis=0))*1e6
+        counts = global_filter_counts(counts, thr=self.global_filter_thr)
+        counts = local_filter_counts(counts, thr=self.filter_thr)
+        filtered_count_mat[self.pools] = counts
+        self.count_mat = filtered_count_mat
+        
+    
+        unambiguous_data, ambiguous_data= get_ambiguity(self)
+        unambiguous_locations =  get_unambiguous_locations(unambiguous_data, self)
+        ambiguous_locations = predict_ambiguous_locations(ambiguous_data, self)
+        locations = pd.concat([unambiguous_locations, ambiguous_locations])
+        temppath = os.path.join("temp", "locations.csv")
+        locations.to_csv(temppath)
+      
 
 # experiment = LibraryExperiment(8,30,10,"gb_ref/UTI89.gb", "bowtie_ref/UTI89", 
 #                                 "AGATGTGTATAAGAGACAG", 1, "input", "barcodes.csv",
